Re:Clojure to Rust rewrite yields 17x speedup
by cljuser on Tuesday July 09, 2019 @07:44PM
(#20397912)
Clojure’s support for non boxed math is error prone and almost unusable. It’s support for non boxed collections is bolted on. Writing code like this in Clojure is a mess.
[ Parent
| on HN ]
There are no comments on this comment yet.